==> webapp-manager_1.2.8.tar.xz: webapp-manager/README.md <==
# Webapp Manager
![build](https://github.com/linuxmint/webapp-manager/actions/workflows/build.yml/badge.svg)

Run websites as if they were apps.

FAQ
===

How to go back without the navigation buttons?
----------------------------------------------

Right-click an empty area of the Web page to show the context menu. In most browsers this menu contains navigation buttons.

How to open links in my main browser?
-------------------------------------

For Firefox, all links are always opened within the WebApp, either directly or using a new tab.
To open a link in your main browser, right-click anywhere, select `Copy link location` and paste the link in your main browser. 

Chromium and Chrome WebApps open external links in the main browser.

How to use tabs in Firefox?
---------------------------

Press <kbd>Ctrl</kbd>+<kbd>Tab</kbd> to cycle between opened tabs.

Press <kbd>Ctrl</kbd>+<kbd>T</kbd> to create a new tab.

Press <kbd>Ctrl</kbd>+<kbd>W</kbd> to close the current tab.

Press <kbd>Ctrl</kbd> when clicking a link to open it in a new tab.

How to add extensions in Firefox (AdBlock etc.)?
------------------------------------------------

Press and release the <kbd>Alt</kbd> key to show the main menubar.

You can then reach the `Add-Ons` from the `Tool` menu.

How to add extensions in Chromium based browsers (AdBlock etc.)?
----------------------------------------------------------------

Press <kbd>Ctrl</kbd>+<kbd>N</kbd> to open a new window.

Navigate to https://chrome.google.com/webstore/category/extensions

Now add the extension.

==> webapp-manager_1.4.6.tar.xz: webapp-manager/README.md <==
# Webapp Manager
![build](https://github.com/linuxmint/webapp-manager/actions/workflows/build.yml/badge.svg)

Run websites as if they were apps.

FAQ
===

How to go back without the navigation buttons?
----------------------------------------------

Right-click an empty area of the Web page to show the context menu. In most browsers this menu contains navigation buttons.

How to open links in my main browser?
-------------------------------------

For Firefox, all links are always opened within the WebApp, either directly or using a new tab.
To open a link in your main browser, right-click anywhere, select `Copy link location` and paste the link in your main browser. 

Chromium and Chrome WebApps open external links in the main browser.

How to use tabs in Firefox?
---------------------------

Press <kbd>Ctrl</kbd>+<kbd>Tab</kbd> to cycle between opened tabs.

Press <kbd>Ctrl</kbd>+<kbd>T</kbd> to create a new tab.

Press <kbd>Ctrl</kbd>+<kbd>W</kbd> to close the current tab.

Press <kbd>Ctrl</kbd> when clicking a link to open it in a new tab.

How to allow new windows to open in Firefox instead of new tabs?
----------------------------------------------------------------

Press and release the <kbd>Alt</kbd> key to show the main menubar.

You can then reach the `Settings` from the `Edit` menu.

In the `General` settings tab, go to the `Tabs` section, uncheck `Open links in tabs instead of new windows`.

In the `Privacy & Security` section, go to `Permissions` and create an exception for your webapp's URL, by pressing the `Exceptions...` button next to it and then adding the respective URL to the list in the following pop-up window.

With this setting, new windows of the webapp will open instead of new tabs, e.g., if you follow links.

How to add extensions in Firefox (AdBlock etc.)?
------------------------------------------------

Press and release the <kbd>Alt</kbd> key to show the main menubar.

You can then reach the `Add-Ons` from the `Tool` menu.

How to add extensions in Chromium based browsers (AdBlock etc.)?
----------------------------------------------------------------

Press <kbd>Ctrl</kbd>+<kbd>N</kbd> to open a new window.

Navigate to https://chrome.google.com/webstore/category/extensions

Now add the extension.
